summaryrefslogtreecommitdiffstats
path: root/kpat/freecell-solver/state.h
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-16 09:58:53 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-16 09:58:53 -0600
commit84ace1135cac57993b72fee7105b92def1638d32 (patch)
treeb8871eb76e3db4a062731b0ce7c99c24fac119e8 /kpat/freecell-solver/state.h
parent97d1732e257f8700488d7ca1660ae7eba8fc6065 (diff)
downloadtdegames-84ace1135cac57993b72fee7105b92def1638d32.tar.gz
tdegames-84ace1135cac57993b72fee7105b92def1638d32.zip
Revert "Rename a number of old tq methods that are no longer tq specific"
This reverts commit 97d1732e257f8700488d7ca1660ae7eba8fc6065.
Diffstat (limited to 'kpat/freecell-solver/state.h')
-rw-r--r--kpat/freecell-solver/state.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/kpat/freecell-solver/state.h b/kpat/freecell-solver/state.h
index e52b717c..302d6d9a 100644
--- a/kpat/freecell-solver/state.h
+++ b/kpat/freecell-solver/state.h
@@ -77,7 +77,7 @@ struct fcs_struct_state_with_locations_t
int depth;
int visited;
int visited_iter;
- int num_active_children;
+ int num_active_tqchildren;
int scan_visited[MAX_NUM_SCANS_BUCKETS];
};
@@ -237,7 +237,7 @@ struct fcs_struct_state_with_locations_t
int depth;
int visited;
int visited_iter;
- int num_active_children;
+ int num_active_tqchildren;
int scan_visited[MAX_NUM_SCANS_BUCKETS];
};
@@ -508,11 +508,11 @@ struct fcs_struct_state_with_locations_t
* */
int visited_iter;
/*
* This is the number of direct children of this state which were not
* yet declared as dead ends. Once this counter reaches zero, this
* state too is declared as a dead end.
* */
- int num_active_children;
+ int num_active_tqchildren;
/*
* This is a vector of flags - one for each scan. Each indicates whether
* its scan has already visited this state
@@ -508,11 +508,11 @@ struct fcs_struct_state_with_locations_t
int visited_iter;
/*
- * This is the number of direct children of this state which were not
+ * This is the number of direct tqchildren of this state which were not
* yet declared as dead ends. Once this counter reaches zero, this
* state too is declared as a dead end.